#####################################################################################
# Plot Smartblade2 data provided by                                                 #
# Contact: Dr.-Ing. Christian Willberg christian.willberg@dlr.de                    #
# leichtbau.dlr.de                                                                  #
# doi: 10.5281/zenodo.3628356                                                       #
# The authors like to thank the German Federal Ministry for Economic                # 
# Affairs and Energy for the funding (Funding number: 0324032) and the members      #
# of the Research Alliance Wind Energy for the project organization and discussion. #
#####################################################################################
import tkinter as tk
import matplotlib.pyplot as plt
import matplotlib
matplotlib.use("TkAgg")
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg #, NavigationToolbar2TkAgg
from matplotlib.figure import Figure
import pandas as pd

class Application(tk.Frame):
    def __init__(self):
        self.type = ''
        self.component = ''
        self.radius = ''
        
        
        self.button_SSB = ''
        self.button_RSB = ''
        self.button_R5000SS = ''
        self.button_R5000PS = ''
        self.button_R8000SS = ''
        self.button_R8000PS = ''
        self.button_R11000 = ''
        self.button_R13000 = ''
        self.button_R15000 = ''
        self.button_R17000 = ''
        self.button_R6700 = ''
        self.button_R9700 = ''
        self.button_R14000 = ''
        self.button_R17700 = ''
        self.button_MXMin = ''
        self.button_MYMin = ''
        self.button_MXMax = ''
        self.button_MYMax = ''

        self.fig = Figure(figsize=(5,5), dpi=100)
        self.a = self.fig.add_subplot(111)
        
        self.canvas = FigureCanvasTkAgg(self.fig,frame)
        
        height = 800
        yVal = 90
        #self.canvas.get_tk_widget().pack(side=tk.BOTTOM , fill=tk.BOTH, expand=0.7)
        self.canvas.get_tk_widget().place(x=0, y=yVal, width=900, height=height)
        self.label1 = tk.Label(frame, text = "Provided by Dr.-Ing. Christian Willberg", font=("Courier", 16))
        self.label2 = tk.Label(frame, text = "German Aerospace Center: christian.willberg@dlr.de", font=("Courier", 16))
        self.label3 = tk.Label(frame, text = " doi: 10.5281/zenodo.3628356", font=("Courier", 16))
        self.label1.place(x = 0, y = height + yVal + 10, width=1000, height=20)
        self.label2.place(x = 0, y = height + yVal + 30, width=1000, height=20)
        self.label3.place(x = 0, y = height + yVal + 50, width=1000, height=20)
    def createLoadCaseButtons(self):
        if self.button_MXMin!='':
            self.button_MXMin.destroy()
            self.button_MYMin.destroy()
            self.button_MXMax.destroy()
            self.button_MYMax.destroy()

        self.button_MXMin = tk.Button(master = frame, text = 'MxMin', fg = 'black', command = lambda: self.setLoadCase('MXMIN'))
        self.button_MXMin.place(x=0, y=60, width=50, height=20)
        self.button_MYMin = tk.Button(master = frame, text = 'MyMin', fg = 'black', command = lambda: self.setLoadCase('MYMIN'))
        self.button_MYMin.place(x=60, y=60, width=50, height=20)
        self.button_MXMax = tk.Button(master = frame, text = 'MxMax', fg = 'black', command = lambda: self.setLoadCase('MXMAX'))
        self.button_MXMax.place(x=120, y=60, width=50, height=20)
        self.button_MYMax = tk.Button(master =  frame, text = 'MyMax', fg = 'black', command = lambda: self.setLoadCase('MYMAX'))
        self.button_MYMax.place(x=180, y=60, width=50, height=20)
    def createComponentButtons(self):    
        button_Displacements = tk.Button(master = frame, text = 'Displacements', fg = 'black', command = lambda: self.setComponent('disp'))
        button_Displacements.place(x=0, y=0, width=100, height=20)
        button_Displacements = tk.Button(master = frame, text = 'Torsion - Displacements', fg = 'black', command = lambda: self.setComponent('Tordisp'))
        button_Displacements.place(x=110, y=0, width=140, height=20)
        button_Exx = tk.Button(master = frame, text = 'Exx', fg = 'black', command = lambda: self.setComponent('StrainXX'))
        button_Exx.place(x=260, y=0, width=50, height=20)
        button_Eyy = tk.Button(master = frame, text = 'Eyy', fg = 'black', command = lambda: self.setComponent('StrainYY'))
        button_Eyy.place(x=320, y=0, width=50, height=20)

    def createRadiusButtons(self, component): 
        if self.button_R5000SS != '': 
            #self.button_R1600.destroy()
            self.button_SSB.destroy()
            self.button_PSB.destroy()
            self.button_R5000SS.destroy()
            self.button_R8000SS.destroy()
            self.button_R5000PS.destroy()
            self.button_R8000PS.destroy()
            self.button_R6700.destroy()
            self.button_R9700.destroy()
            self.button_R14000.destroy()
            self.button_R17700.destroy()
        if self.button_MXMin!='':    
            self.button_MXMin.destroy()
            self.button_MYMin.destroy()
            self.button_MXMax.destroy()
            self.button_MYMax.destroy()

        #self.button_R1600 = tk.Button(master = frame, text = 'R1600', fg = 'black', command = lambda: self.setRadius('1600'))
        #self.button_R1600.place(x=0, y=60, width=60, height=20)
        self.button_R5000SS = tk.Button(master = frame, text = 'SS R5000', fg = 'black', command = lambda: self.setRadius('5000SS'))
        self.button_R5000SS.place(x=0, y=30, width=60, height=20)
        self.button_R8000SS = tk.Button(master = frame, text = 'SS R8000', fg = 'black', command = lambda: self.setRadius('8000SS'))
        self.button_R8000SS.place(x=70, y=30, width=60, height=20)
        self.button_R5000PS = tk.Button(master = frame, text = 'PS R5000', fg = 'black', command = lambda: self.setRadius('5000PS'))
        self.button_R5000PS.place(x=140, y=30, width=60, height=20)
        self.button_R8000PS = tk.Button(master = frame, text = 'PS R8000', fg = 'black', command = lambda: self.setRadius('8000PS'))
        self.button_R8000PS.place(x=210, y=30, width=60, height=20)
        self.button_SSB = tk.Button(master = frame, text = 'SS Belt', fg = 'black', command = lambda: self.setRadius('SSB'))
        self.button_SSB.place(x=280, y=30, width=60, height=20)
        self.button_PSB = tk.Button(master = frame, text = 'PS Belt', fg = 'black', command = lambda: self.setRadius('PSB'))
        self.button_PSB.place(x=350, y=30, width=60, height=20)
        self.button_R6700 = tk.Button(master = frame, text = 'R6700', fg = 'black', command = lambda: self.setRadius('6700'))
        self.button_R6700.place(x=0, y=30, width=60, height=20)
        self.button_R9700 = tk.Button(master = frame, text = 'R9700', fg = 'black', command = lambda: self.setRadius('9700'))
        self.button_R9700.place(x=70, y=30, width=60, height=20)
        self.button_R14000 = tk.Button(master = frame, text = 'R14000', fg = 'black', command = lambda: self.setRadius('14000'))
        self.button_R14000.place(x=140, y=30, width=60, height=20)
        self.button_R17700 = tk.Button(master = frame, text = 'R17700', fg = 'black', command = lambda: self.setRadius('17700'))
        self.button_R17700.place(x=210, y=30, width=60, height=20)
        if component == 'disp' or component == 'Tordisp': 
            #self.button_R1600.destroy()
            self.button_SSB.destroy()
            self.button_PSB.destroy()
            self.button_R5000SS.destroy()
            self.button_R8000SS.destroy()
            self.button_R5000PS.destroy()
            self.button_R8000PS.destroy()

        if component != '' and component != 'disp' and component != 'Tordisp':
            self.button_R6700.destroy()
            self.button_R9700.destroy()
            self.button_R14000.destroy()
            self.button_R17700.destroy()
            if component == 'StrainYY':
                    self.button_SSB.destroy()
                    self.button_PSB.destroy()
    def setLoadCase(self, type):
        self.type = type
        figure = self.plotFigure(self.type, self.component, self.radius)
        
        
    def setRadius(self, type):
        self.radius = type
        if type in ['5000SS', '8000SS','5000PS', '8000PS', 'SSB', 'PSB']:
            self.createLoadCaseButtons()
        figure = self.plotFigure(self.type, self.component, self.radius)
    def setComponent(self, type):
        self.component = type
        figure = self.plotFigure(self.type, self.component, self.radius)
        self.createRadiusButtons(type)

    def getLoadCase(self):
        return self.type
    def getComponent(self):
        return self.component
    def getRadius(self):
        return self.radius
    def plotFigure(self, type, component, radius): #, strain):
        self.a.clear()
        explanation = ''
        if type != '':
            pathType = type 

        if self.component == 'disp' and radius in ['6700', '9700', '14000', '17700']:
            pathComponent = "Displacements"
            LC1 = pd.read_csv('./'+pathComponent+'/MxMin' + radius +'.csv',sep=';',  index_col=False)
            LC2 = pd.read_csv('./'+pathComponent+'/MyMin' + radius +'.csv',sep=';',  index_col=False)  
            LC3 = pd.read_csv('./'+pathComponent+'/MxMax' + radius +'.csv',sep=';',  index_col=False)  
            LC4 = pd.read_csv('./'+pathComponent+'/MyMax' + radius +'.csv',sep=';',  index_col=False)
            explanation= 'Data is given in ./'+pathComponent+'/M ... .csv'
            LC1.plot('xe', 'ye', ax = self.a)
            LC1.plot('xs', 'ys', ax = self.a)
            LC2.plot('xe', 'ye', ax = self.a)
            LC2.plot('xs', 'ys', ax = self.a)
            LC3.plot('xe', 'ye', ax = self.a)
            LC3.plot('xs', 'ys', ax = self.a)
            LC4.plot('xe', 'ye', ax = self.a)
            LC4.plot('xs', 'ys', ax = self.a)
            
            self.a.legend(['MxMin Exp', 'MxMin Sim', 'MyMin Exp', 'MyMin Sim', 'MxMax Exp', 'MxMax Sim', 'MyMax Exp', 'MyMax Sim'])
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Displacements [mm]')
            self.a.set_ylim(0, 1.1*max(LC4['ys']))
            
        if self.component == 'Tordisp' and radius in ['6700', '9700', '14000', '17700']:
            pathComponent = "Torsion"
            LC1 = pd.read_csv('./'+pathComponent+'/LC_1_' + radius +'.csv',sep=';',  index_col=False)
            LC2 = pd.read_csv('./'+pathComponent+'/LC_2_' + radius +'.csv',sep=';',  index_col=False)  
            LC3 = pd.read_csv('./'+pathComponent+'/LC_3_' + radius +'.csv',sep=';',  index_col=False)  

            LC1.plot('xe', 'ye', ax = self.a)
            LC1.plot('xs', 'ys', ax = self.a)
            LC2.plot('xe', 'ye', ax = self.a)
            LC2.plot('xs', 'ys', ax = self.a)
            LC3.plot('xe', 'ye', ax = self.a)
            LC3.plot('xs', 'ys', ax = self.a)
            
            explanation= 'Data is given in ./'+pathComponent+'/LC ... .csv'
            self.a.legend(['LC_1 Exp', 'LC_1 Sim', 'LC_2 Exp', 'LC_2 Sim', 'LC_3 Exp', 'LC_3 Sim'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Displacements [mm]')
        ################ EPSXX #################
        if component == 'StrainXX' and radius =='5000SS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_5000_xplot_SS_epsx.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_5000_xplot_SS_epsx.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_022_Z05000_SS_LE_00.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_048_Z05000_SS_TE__00.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_052_Z05000_SS_TE_OPL1_00.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_054_Z05000_SS_TE_OPL2_00.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_056_Z05000_SS_TE_OPL3_00.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_058_Z05000_SS_TE_OPL4_00.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_060_Z05000_SS_SC__00.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_064_Z05000_SS_LE_OPL3_00.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_066_Z05000_SS_LE_OPL2_00.txt',sep=',',  index_col=False)
            LC11 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_SS_epsx_Sensor_068_Z05000_SS_LE_OPL1_00.txt',sep=',',  index_col=False)
            LC1.plot('Distance_from_leading_edge', 'epsx', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='<')
            LC11.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='>')

            self.a.legend(['Sim', 'Sensor 22', 'Sensor 48', 'Sensor 52', 'Sensor 54', 'Sensor 56', 'Sensor 58', 'Sensor 60', 'Sensor 64', 'Sensor 66', 'Sensor 68'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain xx [-]')
        if component == 'StrainXX' and radius =='5000PS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_5000_xplot_PS_epsx.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_5000_xplot_PS_epsx.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_024_Z05000_PS_LE_00.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_028_Z05000_PS_LE_OPL1_00.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_030_Z05000_PS_LE_OPL2_00.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_032_Z05000_PS_LE_OPL3_00.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_034_Z05000_PS_SC__00.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_038_Z05000_PS_TE_OPL4_00.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_040_Z05000_PS_TE_OPL3_00.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_042_Z05000_PS_TE_OPL2_00.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_044_Z05000_PS_TE_OPL1_00.txt',sep=',',  index_col=False)
            LC11 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_xplot_PS_epsx_Sensor_046_Z05000_PS_TE__00.txt',sep=',',  index_col=False)
            
            LC1.plot('Distance_from_leading_edge', 'epsx', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='<')            
            LC11.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='>')  
            self.a.legend(['Sim', 'Sensor 24', 'Sensor 28', 'Sensor 30', 'Sensor 32', 'Sensor 34', 'Sensor 38', 'Sensor 40', 'Sensor 42', 'Sensor 44', 'Sensor 46'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain xx [-]')
        
        if component == 'StrainXX' and radius =='8000SS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_8000_xplot_SS_epsx.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_8000_xplot_SS_epsx.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_070_Z08000_SS_LE_00.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_094_Z08000_SS_TE__00.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_098_Z08000_SS_TE_OPL1_00.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_100_Z08000_SS_TE_OPL2_00.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_102_Z08000_SS_TE_OPL3_00.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_104_Z08000_SS_TE_OPL4_00.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_106_Z08000_SS_SC__00.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_110_Z08000_SS_LE_OPL2_00.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_SS_epsx_Sensor_112_Z08000_SS_LE_OPL1_00.txt',sep=',',  index_col=False)
            
            LC1.plot('Distance_from_leading_edge', 'epsx', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='<')            

            self.a.legend(['Sim', 'Sensor 70', 'Sensor 94', 'Sensor 98', 'Sensor 100', 'Sensor 102', 'Sensor 104', 'Sensor 106', 'Sensor 110', 'Sensor 112'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain xx [-]')
        if component == 'StrainXX' and radius =='8000PS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_8000_xplot_PS_epsx.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_8000_xplot_PS_epsx.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_072_Z08000_PS_LE_00.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_076_Z08000_PS_LE_OPL1_00.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_078_Z08000_PS_LE_OPL2_00.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_080_Z08000_PS_SC__00.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_084_Z08000_PS_TE_OPL4_00.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_086_Z08000_PS_TE_OPL3_00.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_088_Z08000_PS_TE_OPL2_00.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_090_Z08000_PS_TE_OPL1_00.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_xplot_PS_epsx_Sensor_092_Z08000_PS_TE__00.txt',sep=',',  index_col=False)
            
            LC1.plot('Distance_from_leading_edge', 'epsx', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='<')            
             
            self.a.legend(['Sim', 'Sensor 72', 'Sensor 76', 'Sensor 78', 'Sensor 80', 'Sensor 84', 'Sensor 86', 'Sensor 88', 'Sensor 90', 'Sensor 92'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain xx [-]')
        ################ EPSYY #################
        if component == 'StrainYY' and radius =='5000SS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_5000_yplot_SS_epsy.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_5000_yplot_SS_epsy.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_023_Z05000_SS_LE_90.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_049_Z05000_SS_TE__90.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_053_Z05000_SS_TE_OPL1_90.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_055_Z05000_SS_TE_OPL2_90.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_057_Z05000_SS_TE_OPL3_90.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_059_Z05000_SS_TE_OPL4_90.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_061_Z05000_SS_SC__90.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_065_Z05000_SS_LE_OPL3_90.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_067_Z05000_SS_LE_OPL2_90.txt',sep=',',  index_col=False)
            LC11 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_SS_epsy_Sensor_069_Z05000_SS_LE_OPL1_90.txt',sep=',',  index_col=False)
            LC1.plot('Distance_from_leading_edge', 'epsy', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='<')
            LC11.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='>')
            
            self.a.legend(['Sim', 'Sensor 23', 'Sensor 49', 'Sensor 53', 'Sensor 55', 'Sensor 57', 'Sensor 59', 'Sensor 61', 'Sensor 65', 'Sensor 67', 'Sensor 69'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain yy [-]')
        if component == 'StrainYY' and radius =='5000PS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_5000_yplot_PS_epsy.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_5000_yplot_PS_epsy.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_025_Z05000_PS_LE_90.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_029_Z05000_PS_LE_OPL1_90.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_031_Z05000_PS_LE_OPL2_90.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_033_Z05000_PS_LE_OPL3_90.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_035_Z05000_PS_SC__90.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_039_Z05000_PS_TE_OPL4_90.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_041_Z05000_PS_TE_OPL3_90.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_043_Z05000_PS_TE_OPL2_90.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_045_Z05000_PS_TE_OPL1_90.txt',sep=',',  index_col=False)
            LC11 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_5000_yplot_PS_epsy_Sensor_047_Z05000_PS_TE__90.txt',sep=',',  index_col=False)
            
            LC1.plot('Distance_from_leading_edge', 'epsy', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='<')            
            LC11.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='>')
            self.a.legend(['Sim', 'Sensor 25', 'Sensor 29', 'Sensor 31', 'Sensor 33', 'Sensor 35', 'Sensor 39', 'Sensor 41', 'Sensor 43', 'Sensor 45', 'Sensor 47'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain yy [-]')
        
        if component == 'StrainYY' and radius =='8000SS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_8000_yplot_SS_epsy.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_8000_yplot_SS_epsy.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_071_Z08000_SS_LE_90.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_095_Z08000_SS_TE__90.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_099_Z08000_SS_TE_OPL1_90.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_101_Z08000_SS_TE_OPL2_90.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_103_Z08000_SS_TE_OPL3_90.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_105_Z08000_SS_TE_OPL4_90.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_107_Z08000_SS_SC__90.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_111_Z08000_SS_LE_OPL2_90.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_SS_epsy_Sensor_113_Z08000_SS_LE_OPL1_90.txt',sep=',',  index_col=False)
            
            LC1.plot('Distance_from_leading_edge', 'epsy', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='<')            

            self.a.legend(['Sim', 'Sensor 71', 'Sensor 95', 'Sensor 98', 'Sensor 101', 'Sensor 103', 'Sensor 105', 'Sensor 107', 'Sensor 111', 'Sensor 113'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain yy [-]')
        if component == 'StrainYY' and radius =='8000PS' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_8000_yplot_PS_epsy.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_8000_yplot_PS_epsy.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_073_Z08000_PS_LE_90.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_077_Z08000_PS_LE_OPL1_90.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_079_Z08000_PS_LE_OPL2_90.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_081_Z08000_PS_SC__90.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_085_Z08000_PS_TE_OPL4_90.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_087_Z08000_PS_TE_OPL3_90.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_089_Z08000_PS_TE_OPL2_90.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_091_Z08000_PS_TE_OPL1_90.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_8000_yplot_PS_epsy_Sensor_093_Z08000_PS_TE__90.txt',sep=',',  index_col=False)
            
            LC1.plot('Distance_from_leading_edge', 'epsy', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsy', ax = self.a, style='<')            

            self.a.legend(['Sim', 'Sensor 73', 'Sensor 77', 'Sensor 79', 'Sensor 81', 'Sensor 85', 'Sensor 87', 'Sensor 89', 'Sensor 91', 'Sensor 93'])
            
            self.a.set_xlabel('Distance from leading edge [mm]')
            self.a.set_ylabel('Strain yy [-]')
        ################ Belt #################
        if component == 'StrainXX' and radius == 'SSB' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_top.txt_belt_SS_epsx.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_top.txt_belt_SS_epsx.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-006.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-015.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-021.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-060-061-062-063.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-106-107-108-109.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-122.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-128.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-140-141-142.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_top.txt_belt_SS_epsx_Sensor_Sensor-151.txt',sep=',',  index_col=False)

            LC1.plot('Distance_from_leading_edge', 'epsx', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='<')

            self.a.legend(['Sim', 'Sensor 6', 'Sensor 15', 'Sensor 21', 'Sensor 60', 'Sensor 106', 'Sensor 122', 'Sensor 128', 'Sensor 140', 'Sensor 151'])
            
            self.a.set_xlabel('Distance from root [mm]')
            self.a.set_ylabel('Strain xx [-]')
        if component == 'StrainXX' and radius == 'PSB' and type in ['MXMAX', 'MYMIN', 'MYMAX', 'MXMIN']:
            pathComponent = type
            explanation = './'+pathComponent+'/Simulation_'+type+'_bottom.txt_belt_PS_epsx.txt'
            LC1  = pd.read_csv('./'+pathComponent+'/Simulation_'+type+'_bottom.txt_belt_PS_epsx.txt',sep=',',  index_col=False)
            LC2  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-003.txt',sep=',',  index_col=False)
            LC3  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-012.txt',sep=',',  index_col=False)
            LC4  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-018.txt',sep=',',  index_col=False)
            LC5  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-034-035-036-037.txt',sep=',',  index_col=False)
            LC6  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-080-081-082-083.txt',sep=',',  index_col=False)
            LC7  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-119.txt',sep=',',  index_col=False)
            LC8  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-125.txt',sep=',',  index_col=False)
            LC9  = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-134-135-136.txt',sep=',',  index_col=False)
            LC10 = pd.read_csv('./'+pathComponent+'/Experiment_'+type+'_bottom.txt_belt_PS_epsx_Sensor_Sensor-148.txt',sep=',',  index_col=False)
            
            
            LC1.plot('Distance_from_leading_edge', 'epsx', ax = self.a)
            LC2.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='o')
            LC3.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='x')
            LC4.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='d')
            LC5.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='.')
            LC6.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='*')
            LC7.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='+')
            LC8.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='1')
            LC9.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='^')
            LC10.plot('Distance_from_leading_edge', 'epsx', ax = self.a, style='<')
            
            self.a.legend(['Sim', 'Sensor 3', 'Sensor 12', 'Sensor 18', 'Sensor 34', 'Sensor 80', 'Sensor 119', 'Sensor 125', 'Sensor 134', 'Sensor 148'])
            
            self.a.set_xlabel('Distance from root [mm]')
            self.a.set_ylabel('Strain xx [-]')
        
        
        
        
        
        
        
        self.a.grid()
        self.a.set_title(explanation)    
        self.canvas.draw()


        
        #return figure
        
        
        
        
        
        #self.canvas.draw()
        #self.canvas.get_tk_widget().pack(side=tk.BOTTOM, fill=tk.BOTH, expand=True)

#root = tk.Tk()

frame = tk.Tk()
frame.title('Smartblade2 data')
frame.geometry('1000x1000')
#labelErgebnis.grid(row=4, column=1, padx='5', pady='5', sticky='ew')
app = Application()
#app.createLoadCaseButtons()

app.createComponentButtons()
#app.createRadiusButtons()






frame.mainloop()



